package
Version:
v0.0.0-...-1549b1d
Opens a new window with list of versions in this module.
Published: Aug 10, 2025
License: MIT
Opens a new window with license information.
Imports: 15
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Field contains the information of a field in a struct.
Import contains the information of an import.
LockType represents the type of lock used in a struct.
type Option func(*generator)
Lock sets lock field name to genarator.
Output sets output file path to genarator.
Receiver sets receiver name to genarator.
Type sets type name to genarator.
ParsedSource contains the parsed source of a package.
Struct contains the information of a struct.
Tag contains the information of a struct field's tag.
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.